@@ -1,34 +1,4 @@
-#include <R.h>
-#include <Rmath.h>
-
-void nlgev(double *data, int *n, double *loc, double *scale, double *shape, 
-           double *dns);
-void nlbvalog(double *datam1, double *datam2, int *n, double *dep,
-	      double *asy1, double *asy2, double *loc1, double *scale1, 
-              double *shape1, double *loc2, double *scale2, double *shape2, 
-              double *dns);
-void nlbvlog(double *datam1, double *datam2, int *n, double *dep, 
-	     double *loc1, double *scale1, double *shape1, double *loc2, 
-             double *scale2, double *shape2,  double *dns);
-void nlbvhr(double *datam1, double *datam2, int *n, double *dep, 
-            double *loc1, double *scale1, double *shape1, double *loc2, 
-            double *scale2, double *shape2,  double *dns);
-void nlbvneglog(double *datam1, double *datam2, int *n, double *dep, 
-                double *loc1, double *scale1, double *shape1, double *loc2, 
-                double *scale2, double *shape2,  double *dns);
-void nlbvaneglog(double *datam1, double *datam2, int *n, double *dep,
-	         double *asy1, double *asy2, double *loc1, double *scale1, 
-                 double *shape1, double *loc2, double *scale2, double *shape2, 
-                 double *dns);
-void nlbvbilog(double *datam1, double *datam2, int *n, double *alpha,
-	      double *beta, double *loc1, double *scale1, double *shape1, 
-              double *loc2, double *scale2, double *shape2, double *dns);
-void nlbvnegbilog(double *datam1, double *datam2, int *n, double *alpha,
-	          double *beta, double *loc1, double *scale1, double *shape1, 
-		  double *loc2, double *scale2, double *shape2, double *dns);
-void nlbvct(double *datam1, double *datam2, int *n, double *alpha,
-	    double *beta, double *loc1, double *scale1, double *shape1, 
-            double *loc2, double *scale2, double *shape2, double *dns);
+#include "header.h" 
 
 void nlgev(double *data, int *n, double *loc, double *scale, double *shape, 
            double *dns)
