@@ -16,13 +16,13 @@ pfrechet(2:6, 2, 0.5, 1, low = FALSE)
 drweibull(-1:3, 2, 0.5, log = TRUE)
 dgumbel(-1:3, 0, 1)
 
-rext(4, qexp, rate = 1, mlen = 5)
-rext(4, distn = "exp", rate = 1, mlen = 5)
-rext(4, distn = "exp", mlen = 5)
-rext(1, distn = "norm", sd = 2, mlen = 20, largest = FALSE)
+rextreme(4, qexp, rate = 1, mlen = 5)
+rextreme(4, distn = "exp", rate = 1, mlen = 5)
+rextreme(4, distn = "exp", mlen = 5)
+rextreme(1, distn = "norm", sd = 2, mlen = 20, largest = FALSE)
 min(rnorm(20, mean = 0, sd = 2))
-pext(c(.4, .5), distn = "norm", mean = 0.5, sd = c(1, 2), mlen = 4)
-dext(c(1, 4), distn = "gamma", shape = 1, scale = 0.3, mlen = 100)
+pextreme(c(.4, .5), distn = "norm", mean = 0.5, sd = c(1, 2), mlen = 4)
+dextreme(c(1, 4), distn = "gamma", shape = 1, scale = 0.3, mlen = 100)
 
 rorder(1, distn = "norm", mlen = 20, j = 2)
 rorder(1, distn = "norm", mlen = 20, j = 19, largest = FALSE)
@@ -71,29 +71,29 @@ fitted(m1)
 std.errors(m1)
 anova(m1,m2)
 
-data2 <- rext(100, qnorm, mean = 0.56, mlen = 365)
-nm <- fext(data2, list(mean = 0, sd = 1), distn = "norm", mlen = 365)
+data2 <- rextreme(100, qnorm, mean = 0.56, mlen = 365)
+nm <- fextreme(data2, list(mean = 0, sd = 1), distn = "norm", mlen = 365)
 fitted(nm)
-ga <- fext(data2, list(scale = 1), shape = 0.5, distn = "gamma", mlen = 365, method="L-BFGS-B", lower = 0.01)
+ga <- fextreme(data2, list(scale = 1), shape = 0.5, distn = "gamma", mlen = 365, method="L-BFGS-B", lower = 0.01)
 fitted(ga)
 
 # Section: Fitting Bivariate Distributions by Maximum Likelihood
 
 bvdata <- rbvlog(100, dep = 0.6, mar1 = c(1.2,1.4,0), mar2 = c(1,1.6,0.1))
-m1 <- fbvlog(bvdata)
+m1 <- fbvevd(bvdata, model = "log")
 m1
-m2 <- fbvlog(bvdata, dep = 1)
+m2 <- fbvevd(bvdata, model = "log", dep = 1)
 fitted(m2)
-m3 <- fbvlog(bvdata, shape1 = 0, shape2 = 0)
+m3 <- fbvevd(bvdata, model = "log", shape1 = 0, shape2 = 0)
 anova(m1, m3)
 
 # Boundary Problems
 
-m4 <- fbvalog(bvdata)
+m4 <- fbvevd(bvdata, model = "alog")
 fitted(m4)
-fitted(fbvalog(bvdata, asy1 = 1))
+fitted(fbvevd(bvdata, model = "alog", asy1 = 1))
 upper <- c(rep(Inf, 6), 1, 1, 1) 
-fitted(fbvalog(bvdata, method = "L-BFGS-B", upper = upper))
+fitted(fbvevd(bvdata, model = "alog", method = "L-BFGS-B", upper = upper))
 
 # Section: Extended Example: Oxford Data
 
@@ -110,31 +110,31 @@ anova(ox.fit, ox.fit.gum)
 ox.prof <- profile(ox.fit)
 #ox.prof2d <- profile2d(ox.fit, ox.prof, which = c("scale", "shape"))
 
-ox.qfit <- fgev.quantile(ox, prob = 0.1)
+ox.qfit <- fgev(ox, prob = 0.1)
 ox.qprof <- profile(ox.qfit, which = "quantile")
 
-ox.nm <- fext(ox, list(mean = 40, sd = 1), distn = "norm", mlen = 365)
+ox.nm <- fextreme(ox, list(mean = 40, sd = 1), distn = "norm", mlen = 365)
 fitted(ox.nm)
-ox.ga <- fext(ox, list(scale = 1, shape = 1), distn = "gamma", mlen = 365)
+ox.ga <- fextreme(ox, list(scale = 1, shape = 1), distn = "gamma", mlen = 365)
 fitted(ox.ga)
 
 # Section: Extended Example: Sea Level Data
 
 data(sealevel) ; sl <- sealevel
 tt <- (1912:1992 - 1950)/100
-m1 <- fbvlog(sl, nsloc1 = tt, nsloc2 = tt)
-m2 <- fbvlog(sl, nsloc1 = tt)
-m3 <- fbvlog(sl)
+m1 <- fbvevd(sl, model = "log", nsloc1 = tt, nsloc2 = tt)
+m2 <- fbvevd(sl, model = "log", nsloc1 = tt)
+m3 <- fbvevd(sl, model = "log")
 anova(m1, m2, m3)
 
 tdframe <- data.frame(trend = tt, quad = tt^2)
-m4 <- fbvlog(sl, nsloc1 = tdframe, nsloc2 = tt)
-m5 <- fbvlog(sl, nsloc1 = tt, nsloc2 = tdframe)
-m6 <- fbvlog(sl, nsloc1 = tdframe, nsloc2 = tdframe)
+m4 <- fbvevd(sl, model = "log", nsloc1 = tdframe, nsloc2 = tt)
+m5 <- fbvevd(sl, model = "log", nsloc1 = tt, nsloc2 = tdframe)
+m6 <- fbvevd(sl, model = "log", nsloc1 = tdframe, nsloc2 = tdframe)
 
-m7 <- fbvlog(sl, nsloc1 = tt, nsloc2 = tt, dep = 1)
+m7 <- fbvevd(sl, model = "log", nsloc1 = tt, nsloc2 = tt, dep = 1)
 deviance(m7) - deviance(m1)
-m8 <- fbvlog(sl, nsloc1 = tt, nsloc2 = tt, shape1 = 0, shape2 = 0)
+m8 <- fbvevd(sl, model = "log", nsloc1 = tt, nsloc2 = tt, shape1 = 0, shape2 = 0)
 anova(m1, m8)
 
 #m1.prof <- profile(m1, which = "dep", xmax = 1)
@@ -143,4 +143,4 @@ anova(m1, m8)
 #m.all$dep.summary
 #m.all$criteria
 
-m9 <- fbvalog(sl, nsloc1 = tt, nsloc2 = tt)
+m9 <- fbvevd(sl, model = "alog", nsloc1 = tt, nsloc2 = tt)
